@@ -13,7 +13,7 @@ function print_info {
   printf "======================\n"
 }
 
-TIMESTAMP=`date +%y%m%d%H%M`
+TIMESTAMP=$(git log -1 --format="%at" | xargs -I{} date -d @{} +%y%m%d%H%M)
 GITREF=`git rev-parse --short HEAD`
 RELEASE=r${TIMESTAMP}git${GITREF}
 BUILD="devel"
@@ -33,8 +33,7 @@ DIST=$(rpm --eval "%{dist}" | cut -d. -f2)
 DISTNAME=${DIST}
 
 # Special handling of FC rawhide
-[[ "${DISTNAME}" == "fc39" ]] && DISTNAME="fc-rawhide"
-[[ "${DISTNAME}" == "fc40" ]] && DISTNAME="fc-rawhide"
+[[ "${DISTNAME}" == "fc41" ]] && DISTNAME="fc-rawhide"
 
 # Write repository files to /etc/yum.repos.d/ based on the branch name
 REPO_FILE=$(./ci/write-repo-file.sh)
@@ -45,12 +44,6 @@ SRPMS=${RPMBUILD}/SRPMS
 
 cd packaging/
 make srpm RELEASE=${RELEASE} RPMBUILD=${RPMBUILD} SRPMS=${SRPMS} RPMBUILD_SRC_EXTRA_FLAGS="${RPMBUILD_FLAGS}"
-
-if [[ -f /usr/bin/dnf ]]; then
-  dnf install -y epel-release || true
-  dnf builddep -y ${SRPMS}/*
-else
-  yum-builddep -y ${SRPMS}/*
-fi
+dnf builddep -y ${SRPMS}/*
 
 rpmbuild --rebuild --define="_topdir ${RPMBUILD}" ${RPMBUILD_FLAGS} ${SRPMS}/*
